@@ -1,45 +1,32 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CHECKPHISHINGURLCACHE_H
-#define CHECKPHISHINGURLCACHE_H
+#pragma once
 
 #include "webengineviewer_export.h"
 #include <QObject>
 #include <QUrl>
 
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class CheckPhishingUrlCachePrivate;
+/**
+ * @brief The CheckPhishingUrlCache class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class WEBENGINEVIEWER_EXPORT CheckPhishingUrlCache : public QObject
 {
     Q_OBJECT
 public:
     static CheckPhishingUrlCache *self();
 
-    enum UrlStatus {
-        UrlOk = 0,
-        MalWare = 1,
-        Unknown = 2
-    };
+    enum UrlStatus { UrlOk = 0, MalWare = 1, Unknown = 2 };
 
     explicit CheckPhishingUrlCache(QObject *parent = nullptr);
-    ~CheckPhishingUrlCache();
+    ~CheckPhishingUrlCache() override;
 
     /**
      * @brief addCheckingUrlResult cache url. If @p correctUrl is true we store as UrlOk otherwise MalWare
@@ -58,6 +45,7 @@ public:
      * @brief clearCache clear the cache and save result in config file.
      */
     void clearCache();
+
 private:
     CheckPhishingUrlCachePrivate *const d;
 };
@@ -65,4 +53,3 @@ private:
 
 Q_DECLARE_METATYPE(WebEngineViewer::CheckPhishingUrlCache::UrlStatus)
 
-#endif // CHECKPHISHINGURLCACHE_H
